@@ -101,10 +101,11 @@ static GtkWidget *b_paste;
  * @param user_data builder context (unused)
  */
 void
-gnunet_conversation_gtk_contact_list_treeview_row_activated_cb  (GtkTreeView *tree_view,
-                                                                 GtkTreePath *path,
-                                                                 GtkTreeViewColumn *column,
-                                                                 gpointer user_data)
+gnunet_conversation_gtk_contact_list_treeview_row_activated_cb (
+  GtkTreeView *tree_view,
+  GtkTreePath *path,
+  GtkTreeViewColumn *column,
+  gpointer user_data)
 {
   char *address;
   gchar *type;
@@ -114,38 +115,31 @@ gnunet_conversation_gtk_contact_list_treeview_row_activated_cb  (GtkTreeView *tr
   const char *tld;
 
   GNUNET_assert (NULL != GCG_ZONES_get_selected_zone (&tld));
-  if (! gtk_tree_model_get_iter (contacts_treemodel,
-                                 &iter,
-                                 path))
+  if (! gtk_tree_model_get_iter (contacts_treemodel, &iter, path))
   {
     GNUNET_break (0);
     return;
   }
   gtk_tree_model_get (contacts_treemodel,
                       &iter,
-                      CONTACTS_LS_NAME, &name,
-                      CONTACTS_LS_TYPE, &type,
+                      CONTACTS_LS_NAME,
+                      &name,
+                      CONTACTS_LS_TYPE,
+                      &type,
                       -1);
   if (0 == strcmp (type, "PKEY"))
   {
-    GNUNET_asprintf (&address,
-                     "phone.%s.%s",
-                     name,
-                     tld);
+    GNUNET_asprintf (&address, "phone.%s.%s", name, tld);
   }
   else
   {
-    GNUNET_asprintf (&address,
-                     "%s.%s",
-                     name,
-                     tld);
+    GNUNET_asprintf (&address, "%s.%s", name, tld);
   }
   g_free (name);
   g_free (type);
-  address_entry = GTK_ENTRY (GCG_get_main_window_object
-                             ("gnunet_conversation_gtk_address_entry"));
-  gtk_entry_set_text (address_entry,
-                      address);
+  address_entry = GTK_ENTRY (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_address_entry"));
+  gtk_entry_set_text (address_entry, address);
   GNUNET_free (address);
 }
 
@@ -175,8 +169,7 @@ display_record (void *cls,
   gboolean is_public;
   char *value;
 
-  GNUNET_NAMESTORE_zone_monitor_next (zone_mon,
-                                      1);
+  GNUNET_NAMESTORE_zone_monitor_next (zone_mon, 1);
   do_display = FALSE;
   value = NULL;
   for (unsigned int i = 0; i < rd_len; i++)
@@ -207,8 +200,8 @@ display_record (void *cls,
                                                 rd[i].data_size);
       if (NULL == value)
       {
-	GNUNET_break (0);
-	return;
+        GNUNET_break (0);
+        return;
       }
       is_public = (0 == (rd[i].flags & GNUNET_GNSRECORD_RF_PRIVATE));
       break;
@@ -222,23 +215,21 @@ display_record (void *cls,
 
   /* check if exists, if so, update or remove */
   update = FALSE;
-  if (gtk_tree_model_get_iter_first (contacts_treemodel,
-                                     &iter))
+  if (gtk_tree_model_get_iter_first (contacts_treemodel, &iter))
   {
     do
     {
       gtk_tree_model_get (contacts_treemodel,
                           &iter,
-                          CONTACTS_LS_NAME, &lname,
+                          CONTACTS_LS_NAME,
+                          &lname,
                           -1);
-      if (0 == strcmp (lname,
-                       rname))
+      if (0 == strcmp (lname, rname))
       {
         if (! do_display)
         {
           /* remove */
-          gtk_list_store_remove (contacts_liststore,
-                                 &iter);
+          gtk_list_store_remove (contacts_liststore, &iter);
           g_free (lname);
           GNUNET_free_non_null (value);
           return;
@@ -248,9 +239,7 @@ display_record (void *cls,
         break;
       }
       g_free (lname);
-    }
-    while (gtk_tree_model_iter_next (contacts_treemodel,
-                                     &iter));
+    } while (gtk_tree_model_iter_next (contacts_treemodel, &iter));
   }
 
   /* insert new record */
@@ -260,15 +249,19 @@ display_record (void *cls,
     return;
   }
   if (! update)
-    gtk_list_store_append (contacts_liststore,
-                           &iter);
+    gtk_list_store_append (contacts_liststore, &iter);
   gtk_list_store_set (contacts_liststore,
                       &iter,
-                      CONTACTS_LS_NAME, rname,
-                      CONTACTS_LS_TYPE, type,
-                      CONTACTS_LS_VALUE, value,
-                      CONTACTS_LS_IS_PUBLIC, is_public,
-                      CONTACTS_LS_IS_EDITABLE, FALSE /* FIXME: editing to be implemented */,
+                      CONTACTS_LS_NAME,
+                      rname,
+                      CONTACTS_LS_TYPE,
+                      type,
+                      CONTACTS_LS_VALUE,
+                      value,
+                      CONTACTS_LS_IS_PUBLIC,
+                      is_public,
+                      CONTACTS_LS_IS_EDITABLE,
+                      FALSE /* FIXME: editing to be implemented */,
                       -1);
   GNUNET_free (value);
 }
@@ -359,9 +352,7 @@ gnunet_conversation_gtk_contacts_zone_combobox_changed_cb (GtkComboBox *widget,
  * @param data NULL
  */
 static void
-handle_paste_data (GtkClipboard *clipboard,
-                   const gchar *text,
-                   gpointer data)
+handle_paste_data (GtkClipboard *clipboard, const gchar *text, gpointer data)
 {
   char *name;
   char *slash;
@@ -369,35 +360,27 @@ handle_paste_data (GtkClipboard *clipboard,
 
   if (NULL == text)
     return; /* clipboard empty */
-  if (0 != strncasecmp ("gnunet://gns/",
-                        text,
-                        strlen ("gnunet://gns/")))
+  if (0 != strncasecmp ("gnunet://gns/", text, strlen ("gnunet://gns/")))
   {
-    GCG_log (_("Invalid URI `%s'\n"),
-             text);
+    GCG_log (_ ("Invalid URI `%s'\n"), text);
     return;
   }
   name = GNUNET_strdup (&text[strlen ("gnunet://gns/")]);
   slash = strchr (name, '/');
-  if ( (NULL != slash) &&
-       ('\0' != slash[1]) )
+  if ((NULL != slash) && ('\0' != slash[1]))
   {
     *slash = '\0';
     label = &slash[1];
-    if (GNUNET_OK !=
-        GNUNET_DNSPARSER_check_label (label))
+    if (GNUNET_OK != GNUNET_DNSPARSER_check_label (label))
     {
-      GCG_log (_("Invalid label `%s' in URI `%s'\n"),
-               label,
-               text);
+      GCG_log (_ ("Invalid label `%s' in URI `%s'\n"), label, text);
       GNUNET_free (name);
       return;
     }
     else
     {
       /* got a label already, try to use it */
-      GSC_get_label_for_name (name,
-                              label);
+      GSC_get_label_for_name (name, label);
       GNUNET_free (name);
       return;
     }
@@ -405,8 +388,7 @@ handle_paste_data (GtkClipboard *clipboard,
   if (NULL != slash)
     *slash = '\0';
   /* don't have a label yet, need to prompt! */
-  GSC_get_label_for_name (name,
-                          NULL);
+  GSC_get_label_for_name (name, NULL);
   GNUNET_free (name);
 }
 
@@ -420,14 +402,12 @@ handle_paste_data (GtkClipboard *clipboard,
  */
 void
 gnunet_conversation_gtk_contacts_paste_button_clicked_cb (GtkButton *button,
-							  gpointer user_data)
+                                                          gpointer user_data)
 {
   GtkClipboard *cb;
 
   cb = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-  gtk_clipboard_request_text (cb,
-                              &handle_paste_data,
-                              NULL);
+  gtk_clipboard_request_text (cb, &handle_paste_data, NULL);
 }
 
 
@@ -437,21 +417,17 @@ gnunet_conversation_gtk_contacts_paste_button_clicked_cb (GtkButton *button,
 void
 GCG_CONTACTS_init ()
 {
-  contacts_treeview
-    = GTK_WIDGET (GCG_get_main_window_object
-		  ("gnunet_conversation_gtk_contact_list_treeview"));
-#if GTK_CHECK_VERSION(3,10,0)
+  contacts_treeview = GTK_WIDGET (GCG_get_main_window_object (
+    "gnunet_conversation_gtk_contact_list_treeview"));
+#if GTK_CHECK_VERSION(3, 10, 0)
   gtk_tree_view_set_activate_on_single_click (GTK_TREE_VIEW (contacts_treeview),
                                               TRUE);
 #endif
-  contacts_liststore
-    = GTK_LIST_STORE (GCG_get_main_window_object
-                      ("gnunet_conversation_gtk_contacts_liststore"));
-  contacts_treemodel
-    = GTK_TREE_MODEL (contacts_liststore);
-  b_paste = GTK_WIDGET (GCG_get_main_window_object
-                        ("gnunet_conversation_gtk_contacts_paste_button"));
-
+  contacts_liststore = GTK_LIST_STORE (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_contacts_liststore"));
+  contacts_treemodel = GTK_TREE_MODEL (contacts_liststore);
+  b_paste = GTK_WIDGET (GCG_get_main_window_object (
+    "gnunet_conversation_gtk_contacts_paste_button"));
 }
 
 
