@@ -78,7 +78,7 @@ clean_up_download_as_context (struct DownloadAsDialogContext *dlc)
   g_object_unref (G_OBJECT (dlc->builder));
   if (NULL != dlc->dirname)
   {
-    if (0 != RMDIR (dlc->dirname))
+    if (0 != rmdir (dlc->dirname))
       GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_WARNING,
                                 "rmdir",
                                 dlc->dirname);
@@ -206,12 +206,12 @@ GNUNET_GTK_save_as_dialog_response_cb (GtkDialog *dialog,
 
 /*
 ** FIXME: implement handling for corner cases:
- * A) Selection changes in search tab while SaveAs dialog is open.
- *    If it's in direct download mode, ignore that; otherwise destroy the dialog.
- * B) Download! is pressed in download panel (or the search result is otherwise
- *    being downloaded without using saveas dialog) while SaveAs dialog is open.
- *    Destroy SaveAs dialog.
- */
+* A) Selection changes in search tab while SaveAs dialog is open.
+*    If it's in direct download mode, ignore that; otherwise destroy the dialog.
+* B) Download! is pressed in download panel (or the search result is otherwise
+*    being downloaded without using saveas dialog) while SaveAs dialog is open.
+*    Destroy SaveAs dialog.
+*/
 static void
 open_saveas_dialog (struct DownloadEntry *de, int download_directly)
 {
@@ -263,11 +263,12 @@ open_saveas_dialog (struct DownloadEntry *de, int download_directly)
 
     dirname = GNUNET_strdup (de->filename);
     basename = (char *) GNUNET_STRINGS_get_short_name (dirname);
-    /* basename now points into 'dirname'; cut 'dirname' off at the '/' before basename */
+    /* basename now points into 'dirname'; cut 'dirname' off at the '/' before
+     * basename */
     if (basename > dirname)
       basename[-1] = '\0';
 
-    if (0 != STAT (dirname, &sbuf))
+    if (0 != stat (dirname, &sbuf))
     {
       if (GNUNET_OK != GNUNET_DISK_directory_create (dirname))
       {
