@@ -42,8 +42,7 @@
  *         parse the URI
  */
 int
-GNUNET_FS_GTK_handle_uri_string (const char *uris,
-				 guint anonymity_level)
+GNUNET_FS_GTK_handle_uri_string (const char *uris, guint anonymity_level)
 {
   struct GNUNET_FS_Uri *uri;
   char *perr;
@@ -66,7 +65,7 @@ GNUNET_FS_GTK_handle_uri_string (const char *uris,
  * @param user_data the `GtkBuilder` of the URI dialog
  */
 void
-GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton * button,
+GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton *button,
                                                       gpointer user_data)
 {
   GtkBuilder *builder = GTK_BUILDER (user_data);
@@ -78,17 +77,18 @@ GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton * button,
   char *uris;
 
   dialog =
-      GTK_WIDGET (gtk_builder_get_object
-                  (builder, "GNUNET_GTK_open_url_window"));
-  tb = GTK_TEXT_BUFFER (gtk_builder_get_object
-                        (builder,
-                         "GNUNET_GTK_open_url_dialog_url_textview_buffer"));
+    GTK_WIDGET (gtk_builder_get_object (builder, "GNUNET_GTK_open_url_window"));
+  tb = GTK_TEXT_BUFFER (
+    gtk_builder_get_object (builder,
+                            "GNUNET_GTK_open_url_dialog_url_textview_buffer"));
   gtk_text_buffer_get_iter_at_offset (tb, &ti_start, 0);
   gtk_text_buffer_get_iter_at_offset (tb, &ti_end, -1);
 
   uris = gtk_text_buffer_get_text (tb, &ti_start, &ti_end, FALSE);
-  if (!GNUNET_GTK_get_selected_anonymity_level
-      (builder, "GNUNET_GTK_open_url_dialog_anonymity_combobox", &anonymity_level))
+  if (! GNUNET_GTK_get_selected_anonymity_level (
+        builder,
+        "GNUNET_GTK_open_url_dialog_anonymity_combobox",
+        &anonymity_level))
   {
     GNUNET_break (0);
     gtk_widget_destroy (dialog);
@@ -96,7 +96,7 @@ GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton * button,
     return;
   }
   GNUNET_break (GNUNET_OK ==
-		GNUNET_FS_GTK_handle_uri_string (uris, anonymity_level));
+                GNUNET_FS_GTK_handle_uri_string (uris, anonymity_level));
   g_free (uris);
   gtk_widget_destroy (dialog);
   g_object_unref (G_OBJECT (builder));
@@ -110,15 +110,14 @@ GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GtkButton * button,
  * @param user_data the 'GtkBuilder' of the URI dialog
  */
 void
-GNUNET_GTK_open_url_dialog_cancel_button_clicked_cb (GtkButton * button,
+GNUNET_GTK_open_url_dialog_cancel_button_clicked_cb (GtkButton *button,
                                                      gpointer user_data)
 {
   GtkBuilder *builder = GTK_BUILDER (user_data);
   GtkWidget *dialog;
 
-  dialog = GTK_WIDGET (gtk_builder_get_object
-		       (builder,
-			"GNUNET_GTK_open_url_window"));
+  dialog =
+    GTK_WIDGET (gtk_builder_get_object (builder, "GNUNET_GTK_open_url_window"));
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
 }
@@ -133,8 +132,8 @@ GNUNET_GTK_open_url_dialog_cancel_button_clicked_cb (GtkButton * button,
  * @return FALSE (allow destruction)
  */
 gboolean
-GNUNET_GTK_open_url_window_delete_event_cb (GtkWidget * widget,
-                                            GdkEvent * event,
+GNUNET_GTK_open_url_window_delete_event_cb (GtkWidget *widget,
+                                            GdkEvent *event,
                                             gpointer user_data)
 {
   GtkBuilder *builder = GTK_BUILDER (user_data);
@@ -153,8 +152,8 @@ GNUNET_GTK_open_url_window_delete_event_cb (GtkWidget * widget,
  * @param user_data the 'GtkBuilder' of the URI dialog
  */
 gboolean
-GNUNET_GTK_open_url_dialog_url_textview_key_press_event_cb (GtkWidget * widget,
-                                                            GdkEventKey * event,
+GNUNET_GTK_open_url_dialog_url_textview_key_press_event_cb (GtkWidget *widget,
+                                                            GdkEventKey *event,
                                                             gpointer user_data)
 {
   GtkBuilder *builder = GTK_BUILDER (user_data);
@@ -162,11 +161,12 @@ GNUNET_GTK_open_url_dialog_url_textview_key_press_event_cb (GtkWidget * widget,
 
   if (event->keyval != GDK_KEY_Return)
     return FALSE;
-  execute = GTK_WIDGET (gtk_builder_get_object (builder,
-						"GNUNET_GTK_open_url_dialog_execute_button"));
+  execute = GTK_WIDGET (
+    gtk_builder_get_object (builder,
+                            "GNUNET_GTK_open_url_dialog_execute_button"));
   if (gtk_widget_get_sensitive (execute))
     GNUNET_GTK_open_url_dialog_execute_button_clicked_cb (GTK_BUTTON (execute),
-							  user_data);
+                                                          user_data);
   return TRUE;
 }
 
@@ -179,9 +179,9 @@ GNUNET_GTK_open_url_dialog_url_textview_key_press_event_cb (GtkWidget * widget,
  * @param user_data the 'GtkBuilder' of the URI dialog
  */
 void
-GNUNET_GTK_open_url_dialog_url_textview_buffer_changed_cb (GtkTextBuffer *
-                                                           textbuffer,
-                                                           gpointer user_data)
+GNUNET_GTK_open_url_dialog_url_textview_buffer_changed_cb (
+  GtkTextBuffer *textbuffer,
+  gpointer user_data)
 {
   GtkBuilder *builder = GTK_BUILDER (user_data);
   struct GNUNET_FS_Uri *uri;
@@ -192,9 +192,9 @@ GNUNET_GTK_open_url_dialog_url_textview_buffer_changed_cb (GtkTextBuffer *
   char *uris;
 
   perr = NULL;
-  tb = GTK_TEXT_BUFFER (gtk_builder_get_object
-                        (builder,
-                         "GNUNET_GTK_open_url_dialog_url_textview_buffer"));
+  tb = GTK_TEXT_BUFFER (
+    gtk_builder_get_object (builder,
+                            "GNUNET_GTK_open_url_dialog_url_textview_buffer"));
   gtk_text_buffer_get_iter_at_offset (tb, &ti_start, 0);
   gtk_text_buffer_get_iter_at_offset (tb, &ti_end, -1);
   uris = gtk_text_buffer_get_text (tb, &ti_start, &ti_end, FALSE);
@@ -203,9 +203,8 @@ GNUNET_GTK_open_url_dialog_url_textview_buffer_changed_cb (GtkTextBuffer *
   else
     uri = NULL;
   g_free (uris);
-  gtk_widget_set_sensitive (GTK_WIDGET
-                            (gtk_builder_get_object
-                             (builder,
+  gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+                              builder,
                               "GNUNET_GTK_open_url_dialog_execute_button")),
                             (uri == NULL) ? FALSE : TRUE);
   if (uri != NULL)
@@ -221,7 +220,7 @@ GNUNET_GTK_open_url_dialog_url_textview_buffer_changed_cb (GtkTextBuffer *
  * @param user_data unused
  */
 void
-GNUNET_GTK_main_menu_file_download_uri_activate_cb (GtkWidget * dummy,
+GNUNET_GTK_main_menu_file_download_uri_activate_cb (GtkWidget *dummy,
                                                     gpointer user_data)
 {
   GtkBuilder *builder;
@@ -239,22 +238,22 @@ GNUNET_GTK_main_menu_file_download_uri_activate_cb (GtkWidget * dummy,
     GNUNET_break (0);
     return;
   }
-  dialog = GTK_WIDGET (gtk_builder_get_object
-		       (builder,
-			"GNUNET_GTK_open_url_window"));
-  tb = GTK_TEXT_BUFFER (gtk_builder_get_object
-                        (builder,
-                         "GNUNET_GTK_open_url_dialog_url_textview_buffer"));
+  dialog =
+    GTK_WIDGET (gtk_builder_get_object (builder, "GNUNET_GTK_open_url_window"));
+  tb = GTK_TEXT_BUFFER (
+    gtk_builder_get_object (builder,
+                            "GNUNET_GTK_open_url_dialog_url_textview_buffer"));
   gtk_text_buffer_get_iter_at_offset (tb, &ti_start, 0);
   gtk_text_buffer_get_iter_at_offset (tb, &ti_end, -1);
   gtk_text_buffer_delete (tb, &ti_start, &ti_end);
 
   /* FIXME-FEATURE: query the clipboard, maybe there's valid URI in there?
    * If so, get it. */
-  combo = GTK_COMBO_BOX (gtk_builder_get_object
-			 (builder,
-			  "GNUNET_GTK_open_url_dialog_anonymity_combobox"));
-  gtk_combo_box_set_model (combo, GNUNET_FS_GTK_get_anonymity_level_list_store ());
+  combo = GTK_COMBO_BOX (
+    gtk_builder_get_object (builder,
+                            "GNUNET_GTK_open_url_dialog_anonymity_combobox"));
+  gtk_combo_box_set_model (combo,
+                           GNUNET_FS_GTK_get_anonymity_level_list_store ());
   toplevel = gtk_widget_get_toplevel (dummy);
   if (GTK_IS_WINDOW (toplevel))
     gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
