@@ -33,47 +33,47 @@
  * Columns in the unindex model.
  */
 enum UNINDEX_ModelColumns
-  {
-    /**
+{
+  /**
      * A gchararray.
      */
-    UNINDEX_MC_FILENAME = 0,
+  UNINDEX_MC_FILENAME = 0,
 
-    /**
+  /**
      * A guint64.
      */
-    UNINDEX_MC_FILESIZE = 1,
+  UNINDEX_MC_FILESIZE = 1,
 
-    /**
+  /**
      * A gchararray representing a color.
      */
-    UNINDEX_MC_BACKGROUND_COLOR = 2,
+  UNINDEX_MC_BACKGROUND_COLOR = 2,
 
-    /**
+  /**
      * A 'struct UnindexEntry' (gpointer)
      */
-    UNINDEX_MC_UNINDEX_CONTEXT = 3,
+  UNINDEX_MC_UNINDEX_CONTEXT = 3,
 
-    /**
+  /**
      * A gfloat.
      */
-    UNINDEX_MC_UNINDEX_PROGRESS = 4,
+  UNINDEX_MC_UNINDEX_PROGRESS = 4,
 
-    /**
+  /**
      * A boolean.
      */
-    UNINDEX_MC_PROGRESS_VISIBLE = 5,
+  UNINDEX_MC_PROGRESS_VISIBLE = 5,
 
-    /**
+  /**
      * A gchararray.
      */
-    UNINDEX_MC_ERROR = 6,
+  UNINDEX_MC_ERROR = 6,
 
-    /**
+  /**
      * A GdkPixbuf.
      */
-    UNINDEX_MC_STATUS_ICON = 7
-  };
+  UNINDEX_MC_STATUS_ICON = 7
+};
 
 
 /**
@@ -187,8 +187,7 @@ static struct UnindexEntry *ue_tail;
  * @param user_data the unindex context
  */
 void
-GNUNET_FS_GTK_unindex_button_clicked_cb (GtkWidget * dummy,
-					 gpointer user_data)
+GNUNET_FS_GTK_unindex_button_clicked_cb (GtkWidget *dummy, gpointer user_data)
 {
   struct UnindexDialogContext *udc = user_data;
   GtkTreeIter iter;
@@ -203,11 +202,15 @@ GNUNET_FS_GTK_unindex_button_clicked_cb (GtkWidget * dummy,
     GNUNET_break (0);
     return;
   }
-  gtk_tree_model_get (udc->model, &iter,
-		      UNINDEX_MC_FILENAME, &filename,
-		      UNINDEX_MC_FILESIZE, &filesize,
-		      UNINDEX_MC_UNINDEX_CONTEXT, &ue,
-		      -1);
+  gtk_tree_model_get (udc->model,
+                      &iter,
+                      UNINDEX_MC_FILENAME,
+                      &filename,
+                      UNINDEX_MC_FILESIZE,
+                      &filesize,
+                      UNINDEX_MC_UNINDEX_CONTEXT,
+                      &ue,
+                      -1);
   if (NULL != ue)
   {
     GNUNET_break (0);
@@ -221,15 +224,19 @@ GNUNET_FS_GTK_unindex_button_clicked_cb (GtkWidget * dummy,
   path = gtk_tree_model_get_path (udc->model, &iter);
   ue->rr = gtk_tree_row_reference_new (udc->model, path);
   gtk_tree_path_free (path);
-  ue->uc = GNUNET_FS_unindex_start (GNUNET_FS_GTK_get_fs_handle (),
-				    filename, ue);
+  ue->uc =
+    GNUNET_FS_unindex_start (GNUNET_FS_GTK_get_fs_handle (), filename, ue);
   gtk_list_store_set (GTK_LIST_STORE (udc->model),
-		      &iter,
-		      UNINDEX_MC_BACKGROUND_COLOR, "yellow",
-		      UNINDEX_MC_UNINDEX_CONTEXT, ue,
-		      UNINDEX_MC_UNINDEX_PROGRESS, 0,
-		      UNINDEX_MC_PROGRESS_VISIBLE, TRUE,
-		      -1);
+                      &iter,
+                      UNINDEX_MC_BACKGROUND_COLOR,
+                      "yellow",
+                      UNINDEX_MC_UNINDEX_CONTEXT,
+                      ue,
+                      UNINDEX_MC_UNINDEX_PROGRESS,
+                      0,
+                      UNINDEX_MC_PROGRESS_VISIBLE,
+                      TRUE,
+                      -1);
   gtk_widget_set_sensitive (udc->unindex_button, FALSE);
 }
 
@@ -241,8 +248,8 @@ GNUNET_FS_GTK_unindex_button_clicked_cb (GtkWidget * dummy,
  * @param user_data the unindex context
  */
 void
-GNUNET_FS_GTK_unindex_close_button_clicked_cb (GtkWidget * dummy,
-					       gpointer user_data)
+GNUNET_FS_GTK_unindex_close_button_clicked_cb (GtkWidget *dummy,
+                                               gpointer user_data)
 {
   struct UnindexDialogContext *udc = user_data;
   GtkTreeIter iter;
@@ -256,16 +263,17 @@ GNUNET_FS_GTK_unindex_close_button_clicked_cb (GtkWidget * dummy,
   if (gtk_tree_model_get_iter_first (udc->model, &iter))
     do
     {
-      gtk_tree_model_get (udc->model, &iter,
-			  UNINDEX_MC_UNINDEX_CONTEXT, &ue,
-			  -1);
+      gtk_tree_model_get (udc->model,
+                          &iter,
+                          UNINDEX_MC_UNINDEX_CONTEXT,
+                          &ue,
+                          -1);
       if (NULL != ue)
       {
-	gtk_tree_row_reference_free (ue->rr);
-	ue->rr = NULL;
+        gtk_tree_row_reference_free (ue->rr);
+        ue->rr = NULL;
       }
-    }
-    while (TRUE == gtk_tree_model_iter_next (udc->model, &iter));
+    } while (TRUE == gtk_tree_model_iter_next (udc->model, &iter));
   gtk_widget_destroy (udc->dialog);
   g_object_unref (G_OBJECT (udc->builder));
   GNUNET_free (udc);
@@ -281,7 +289,7 @@ GNUNET_FS_GTK_unindex_close_button_clicked_cb (GtkWidget * dummy,
  */
 void
 GNUNET_FS_GTK_unindex_treeview_selection_changed_cb (GtkTreeSelection *ts,
-		      gpointer user_data)
+                                                     gpointer user_data)
 {
   struct UnindexDialogContext *udc = user_data;
   GtkTreeIter iter;
@@ -290,9 +298,7 @@ GNUNET_FS_GTK_unindex_treeview_selection_changed_cb (GtkTreeSelection *ts,
   /* find out if a file is selected */
   if (gtk_tree_selection_get_selected (udc->selection, NULL, &iter))
   {
-    gtk_tree_model_get (udc->model, &iter,
-			UNINDEX_MC_UNINDEX_CONTEXT, &ue,
-			-1);
+    gtk_tree_model_get (udc->model, &iter, UNINDEX_MC_UNINDEX_CONTEXT, &ue, -1);
     if (NULL == ue)
     {
       /* selected file not already being unindexed, enable button! */
@@ -313,8 +319,9 @@ GNUNET_FS_GTK_unindex_treeview_selection_changed_cb (GtkTreeSelection *ts,
  * @return GNUNET_OK to continue iteration, GNUNET_SYSERR to abort
  */
 static int
-add_indexed_file (void *cls, const char *filename,
-		  const struct GNUNET_HashCode * file_id)
+add_indexed_file (void *cls,
+                  const char *filename,
+                  const struct GNUNET_HashCode *file_id)
 {
   struct UnindexDialogContext *udc = cls;
   GtkTreeIter iter;
@@ -329,13 +336,11 @@ add_indexed_file (void *cls, const char *filename,
     return GNUNET_OK;
   }
   if (GNUNET_OK !=
-      GNUNET_DISK_file_size (filename,
-			     &filesize,
-			     GNUNET_YES, GNUNET_YES))
+      GNUNET_DISK_file_size (filename, &filesize, GNUNET_YES, GNUNET_YES))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-		_("Could not access indexed file `%s'\n"),
-		filename);
+                _ ("Could not access indexed file `%s'\n"),
+                filename);
     return GNUNET_OK;
   }
   for (ue = ue_head; ue != NULL; ue = ue->next)
@@ -344,12 +349,17 @@ add_indexed_file (void *cls, const char *filename,
   if (NULL == ue)
   {
     gtk_list_store_insert_with_values (GTK_LIST_STORE (udc->model),
-				       &iter, G_MAXINT,
-				       UNINDEX_MC_FILENAME, filename,
-				       UNINDEX_MC_FILESIZE, (guint64) filesize,
-				       UNINDEX_MC_BACKGROUND_COLOR, "white",
-				       UNINDEX_MC_PROGRESS_VISIBLE, FALSE,
-				       -1);
+                                       &iter,
+                                       G_MAXINT,
+                                       UNINDEX_MC_FILENAME,
+                                       filename,
+                                       UNINDEX_MC_FILESIZE,
+                                       (guint64) filesize,
+                                       UNINDEX_MC_BACKGROUND_COLOR,
+                                       "white",
+                                       UNINDEX_MC_PROGRESS_VISIBLE,
+                                       FALSE,
+                                       -1);
   }
   else
   {
@@ -359,15 +369,23 @@ add_indexed_file (void *cls, const char *filename,
       return GNUNET_OK;
     }
     gtk_list_store_insert_with_values (GTK_LIST_STORE (udc->model),
-				       &iter, G_MAXINT,
-				       UNINDEX_MC_FILENAME, filename,
-				       UNINDEX_MC_FILESIZE, (guint64) filesize,
-				       UNINDEX_MC_BACKGROUND_COLOR, (NULL == ue->emsg) ? "yellow" : "red",
-				       UNINDEX_MC_UNINDEX_CONTEXT, ue,
-				       UNINDEX_MC_UNINDEX_PROGRESS, ue->progress,
-				       UNINDEX_MC_PROGRESS_VISIBLE, TRUE,
-				       UNINDEX_MC_ERROR, ue->emsg,
-				       -1);
+                                       &iter,
+                                       G_MAXINT,
+                                       UNINDEX_MC_FILENAME,
+                                       filename,
+                                       UNINDEX_MC_FILESIZE,
+                                       (guint64) filesize,
+                                       UNINDEX_MC_BACKGROUND_COLOR,
+                                       (NULL == ue->emsg) ? "yellow" : "red",
+                                       UNINDEX_MC_UNINDEX_CONTEXT,
+                                       ue,
+                                       UNINDEX_MC_UNINDEX_PROGRESS,
+                                       ue->progress,
+                                       UNINDEX_MC_PROGRESS_VISIBLE,
+                                       TRUE,
+                                       UNINDEX_MC_ERROR,
+                                       ue->emsg,
+                                       -1);
     path = gtk_tree_model_get_path (udc->model, &iter);
     ue->rr = gtk_tree_row_reference_new (udc->model, path);
   }
@@ -382,8 +400,7 @@ add_indexed_file (void *cls, const char *filename,
  * @param data the main dialog builder, unused
  */
 void
-GNUNET_GTK_main_menu_unindex_activate_cb (GtkWidget * dummy,
-					  gpointer data)
+GNUNET_GTK_main_menu_unindex_activate_cb (GtkWidget *dummy, gpointer data)
 {
   GtkWidget *toplevel;
   struct UnindexDialogContext *udc;
@@ -403,21 +420,22 @@ GNUNET_GTK_main_menu_unindex_activate_cb (GtkWidget * dummy,
     GNUNET_free (udc);
     return;
   }
-  udc->dialog = GTK_WIDGET (gtk_builder_get_object
-			   (udc->builder, "GNUNET_FS_GTK_unindex_dialog"));
-  udc->treeview = GTK_TREE_VIEW (gtk_builder_get_object
-				 (udc->builder, "GNUNET_FS_GTK_unindex_treeview"));
+  udc->dialog = GTK_WIDGET (
+    gtk_builder_get_object (udc->builder, "GNUNET_FS_GTK_unindex_dialog"));
+  udc->treeview = GTK_TREE_VIEW (
+    gtk_builder_get_object (udc->builder, "GNUNET_FS_GTK_unindex_treeview"));
   udc->selection = gtk_tree_view_get_selection (udc->treeview);
-  udc->unindex_button = GTK_WIDGET (gtk_builder_get_object
-				   (udc->builder, "GNUNET_FS_GTK_unindex_button"));
-  udc->model = GTK_TREE_MODEL (gtk_builder_get_object
-			      (udc->builder, "GNUNET_FS_GTK_unindex_liststore"));
+  udc->unindex_button = GTK_WIDGET (
+    gtk_builder_get_object (udc->builder, "GNUNET_FS_GTK_unindex_button"));
+  udc->model = GTK_TREE_MODEL (
+    gtk_builder_get_object (udc->builder, "GNUNET_FS_GTK_unindex_liststore"));
   udc->gic = GNUNET_FS_get_indexed_files (GNUNET_FS_GTK_get_fs_handle (),
-					  &add_indexed_file,
-					  udc);
+                                          &add_indexed_file,
+                                          udc);
   toplevel = gtk_widget_get_toplevel (dummy);
   if (GTK_IS_WINDOW (toplevel))
-    gtk_window_set_transient_for (GTK_WINDOW (udc->dialog), GTK_WINDOW (toplevel));
+    gtk_window_set_transient_for (GTK_WINDOW (udc->dialog),
+                                  GTK_WINDOW (toplevel));
   gtk_window_present (GTK_WINDOW (udc->dialog));
   master_udc = udc;
 }
@@ -436,10 +454,10 @@ GNUNET_GTK_main_menu_unindex_activate_cb (GtkWidget * dummy,
  */
 struct UnindexEntry *
 GNUNET_FS_GTK_unindex_handle_resume_ (struct GNUNET_FS_UnindexContext *uc,
-				      const char *filename,
-				      uint64_t filesize,
-				      uint64_t completed,
-				      const char *emsg)
+                                      const char *filename,
+                                      uint64_t filesize,
+                                      uint64_t completed,
+                                      const char *emsg)
 {
   struct UnindexEntry *ue;
 
@@ -450,9 +468,7 @@ GNUNET_FS_GTK_unindex_handle_resume_ (struct GNUNET_FS_UnindexContext *uc,
   ue->filesize = filesize;
   ue->uc = uc;
   ue->progress = (gint) ((100LL * completed) / filesize);
-  GNUNET_CONTAINER_DLL_insert (ue_head,
-			       ue_tail,
-			       ue);
+  GNUNET_CONTAINER_DLL_insert (ue_head, ue_tail, ue);
   return ue;
 }
 
@@ -475,18 +491,15 @@ GNUNET_FS_GTK_unindex_handle_stop_ (struct UnindexEntry *ue)
     model = gtk_tree_row_reference_get_model (ue->rr);
     gtk_tree_row_reference_free (ue->rr);
     ue->rr = NULL;
-    GNUNET_assert (TRUE == gtk_tree_model_get_iter (model,
-						    &iter,
-						    path));
+    GNUNET_assert (TRUE == gtk_tree_model_get_iter (model, &iter, path));
     gtk_tree_path_free (path);
     gtk_list_store_set (GTK_LIST_STORE (model),
-			&iter,
-			UNINDEX_MC_UNINDEX_CONTEXT, NULL,
-			-1);
+                        &iter,
+                        UNINDEX_MC_UNINDEX_CONTEXT,
+                        NULL,
+                        -1);
   }
-  GNUNET_CONTAINER_DLL_remove (ue_head,
-			       ue_tail,
-			       ue);
+  GNUNET_CONTAINER_DLL_remove (ue_head, ue_tail, ue);
   GNUNET_free_non_null (ue->emsg);
   GNUNET_free (ue->filename);
   GNUNET_free (ue);
@@ -500,8 +513,7 @@ GNUNET_FS_GTK_unindex_handle_stop_ (struct UnindexEntry *ue)
  * @param emsg error message
  */
 void
-GNUNET_FS_GTK_unindex_handle_error_ (struct UnindexEntry *ue,
-				     const char *emsg)
+GNUNET_FS_GTK_unindex_handle_error_ (struct UnindexEntry *ue, const char *emsg)
 {
   GtkTreePath *path;
   GtkTreeIter iter;
@@ -512,15 +524,15 @@ GNUNET_FS_GTK_unindex_handle_error_ (struct UnindexEntry *ue,
     return;
   path = gtk_tree_row_reference_get_path (ue->rr);
   model = gtk_tree_row_reference_get_model (ue->rr);
-  GNUNET_assert (TRUE == gtk_tree_model_get_iter (model,
-						  &iter,
-						  path));
+  GNUNET_assert (TRUE == gtk_tree_model_get_iter (model, &iter, path));
   gtk_tree_path_free (path);
   gtk_list_store_set (GTK_LIST_STORE (model),
-		      &iter,
-		      UNINDEX_MC_BACKGROUND_COLOR, "red",
-		      UNINDEX_MC_ERROR, emsg,
-		      -1);
+                      &iter,
+                      UNINDEX_MC_BACKGROUND_COLOR,
+                      "red",
+                      UNINDEX_MC_ERROR,
+                      emsg,
+                      -1);
 }
 
 
@@ -532,7 +544,7 @@ GNUNET_FS_GTK_unindex_handle_error_ (struct UnindexEntry *ue,
  */
 void
 GNUNET_FS_GTK_unindex_handle_progress_ (struct UnindexEntry *ue,
-					uint64_t completed)
+                                        uint64_t completed)
 {
   GtkTreePath *path;
   GtkTreeIter iter;
@@ -543,14 +555,13 @@ GNUNET_FS_GTK_unindex_handle_progress_ (struct UnindexEntry *ue,
     return;
   path = gtk_tree_row_reference_get_path (ue->rr);
   model = gtk_tree_row_reference_get_model (ue->rr);
-  GNUNET_assert (TRUE == gtk_tree_model_get_iter (model,
-						  &iter,
-						  path));
+  GNUNET_assert (TRUE == gtk_tree_model_get_iter (model, &iter, path));
   gtk_tree_path_free (path);
   gtk_list_store_set (GTK_LIST_STORE (model),
-		      &iter,
-		      UNINDEX_MC_UNINDEX_PROGRESS, ue->progress,
-		      -1);
+                      &iter,
+                      UNINDEX_MC_UNINDEX_PROGRESS,
+                      ue->progress,
+                      -1);
 }
 
 
@@ -570,12 +581,9 @@ GNUNET_FS_GTK_unindex_handle_completed_ (struct UnindexEntry *ue)
   {
     path = gtk_tree_row_reference_get_path (ue->rr);
     model = gtk_tree_row_reference_get_model (ue->rr);
-    GNUNET_assert (TRUE == gtk_tree_model_get_iter (model,
-						    &iter,
-						    path));
+    GNUNET_assert (TRUE == gtk_tree_model_get_iter (model, &iter, path));
     gtk_tree_path_free (path);
-    gtk_list_store_remove (GTK_LIST_STORE (model),
-			   &iter);
+    gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
     gtk_tree_row_reference_free (ue->rr);
     ue->rr = NULL;
   }
@@ -583,5 +591,4 @@ GNUNET_FS_GTK_unindex_handle_completed_ (struct UnindexEntry *ue)
 }
 
 
-
 /* end of gnunet-fs-gtk_unindex.c */
