@@ -111,7 +111,7 @@ struct GNUNET_GTK_MainLoop
   /**
    * Remaining command-line arguments.
    */
-  char *const*argv;
+  char *const *argv;
 
   /**
    * Number of remaining arguments.
@@ -172,7 +172,6 @@ struct GNUNET_GTK_MainLoop
    */
   struct GNUNET_CONTAINER_SList *handles_except;
 #endif
-
 };
 
 
@@ -184,8 +183,7 @@ struct GNUNET_GTK_MainLoop
  * @return new main window to initialize
  */
 GtkWidget *
-GNUNET_GTK_plug_me (const char *env_name,
-                    GtkWidget *main_window)
+GNUNET_GTK_plug_me (const char *env_name, GtkWidget *main_window)
 {
 #if HAVE_GTK_GTKX_H
 #ifdef GDK_WINDOWING_X11
@@ -196,22 +194,16 @@ GNUNET_GTK_plug_me (const char *env_name,
 
   if (NULL == (plugid = getenv (env_name)))
     return main_window; /* no plugging */
-  if (1 != sscanf (plugid,
-                   "%llu",
-                   &id))
+  if (1 != sscanf (plugid, "%llu", &id))
   {
-    fprintf (stderr,
-             _("Invalid plug name `%s'\n"),
-             plugid);
+    fprintf (stderr, _ ("Invalid plug name `%s'\n"), plugid);
     return main_window;
   }
   plug = gtk_plug_new ((Window) id);
   child = gtk_bin_get_child (GTK_BIN (main_window));
   g_object_ref (child);
-  gtk_container_remove (GTK_CONTAINER (main_window),
-                        child);
-  gtk_container_add (GTK_CONTAINER (plug),
-                     child);
+  gtk_container_remove (GTK_CONTAINER (main_window), child);
+  gtk_container_add (GTK_CONTAINER (plug), child);
   g_object_unref (child);
   gtk_widget_destroy (main_window);
   return plug;
@@ -270,7 +262,7 @@ GNUNET_GTK_main_loop_get_builder (struct GNUNET_GTK_MainLoop *ml)
 
 int
 GNUNET_GTK_main_loop_build_window (struct GNUNET_GTK_MainLoop *ml,
-				   gpointer data)
+                                   gpointer data)
 {
   ml->builder = GNUNET_GTK_get_new_builder (ml->main_window_file, data);
   if (ml->builder == NULL)
@@ -303,7 +295,7 @@ GNUNET_GTK_main_loop_get_configuration_file (struct GNUNET_GTK_MainLoop *ml)
  * @return NULL on error, otherwise the object
  */
 GObject *
-GNUNET_GTK_main_loop_get_object (struct GNUNET_GTK_MainLoop * ml,
+GNUNET_GTK_main_loop_get_object (struct GNUNET_GTK_MainLoop *ml,
                                  const char *name)
 {
   return gtk_builder_get_object (ml->builder, name);
@@ -318,9 +310,9 @@ GNUNET_GTK_main_loop_get_object (struct GNUNET_GTK_MainLoop * ml,
  * @param argv set to argument vector
  */
 void
-GNUNET_GTK_main_loop_get_args (struct GNUNET_GTK_MainLoop * ml,
-			       int *argc,
-			       char *const**argv)
+GNUNET_GTK_main_loop_get_args (struct GNUNET_GTK_MainLoop *ml,
+                               int *argc,
+                               char *const **argv)
 {
   *argc = ml->argc;
   *argv = ml->argv;
@@ -367,9 +359,9 @@ keepalive_task (void *cls)
   struct GNUNET_GTK_MainLoop *ml = cls;
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Dummy task was scheduled\n");
-  ml->dummy_task
-    = GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_FOREVER_REL,
-				    &keepalive_task, ml);
+  ml->dummy_task = GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_FOREVER_REL,
+                                                 &keepalive_task,
+                                                 ml);
 }
 
 
@@ -420,8 +412,7 @@ struct _select_params_gtk
   int status;
 };
 
-static unsigned __stdcall
-_gnunet_selector_thread (void *p)
+static unsigned __stdcall _gnunet_selector_thread (void *p)
 {
   struct _select_params_gtk *sp = p;
 
@@ -429,7 +420,8 @@ _gnunet_selector_thread (void *p)
   {
     WaitForSingleObject (sp->event_to_wait_for_a_job, INFINITE);
     ResetEvent (sp->event_to_wait_for_a_job);
-    sp->status = GNUNET_NETWORK_socket_select (sp->rfds, sp->wfds, sp->efds, sp->timeout);
+    sp->status =
+      GNUNET_NETWORK_socket_select (sp->rfds, sp->wfds, sp->efds, sp->timeout);
     SetEvent (sp->event_to_signal_we_woke_up);
   }
   return 0;
@@ -518,7 +510,8 @@ gnunet_gtk_select (void *cls,
     wakeup_event_for_gnunet = CreateEvent (NULL, TRUE, FALSE, NULL);
     gnunet_woke_up_event = CreateEvent (NULL, TRUE, FALSE, NULL);
     standin_rfds = GNUNET_NETWORK_fdset_create ();
-    wakeup_event_for_gnunet_fh = GNUNET_DISK_get_handle_from_w32_handle (wakeup_event_for_gnunet);
+    wakeup_event_for_gnunet_fh =
+      GNUNET_DISK_get_handle_from_w32_handle (wakeup_event_for_gnunet);
     gnunet_selector_thread_job_event = CreateEvent (NULL, TRUE, FALSE, NULL);
     sp = GNUNET_new (struct _select_params_gtk);
 
@@ -526,20 +519,20 @@ gnunet_gtk_select (void *cls,
     sp->event_to_that_wakes_us_up = wakeup_event_for_gnunet;
     sp->event_to_wait_for_a_job = gnunet_selector_thread_job_event;
 
-    gnunet_select_subthread = (HANDLE) _beginthreadex (NULL, 0, _gnunet_selector_thread, sp, 0, NULL);
+    gnunet_select_subthread =
+      (HANDLE) _beginthreadex (NULL, 0, _gnunet_selector_thread, sp, 0, NULL);
 
     g_once_init_leave (&initialized, 1);
   }
 
-  if (wakeup_event_for_gnunet == NULL ||
-      gnunet_woke_up_event == NULL ||
-      gnunet_select_subthread == NULL ||
-      wakeup_event_for_gnunet_fh == NULL ||
+  if (wakeup_event_for_gnunet == NULL || gnunet_woke_up_event == NULL ||
+      gnunet_select_subthread == NULL || wakeup_event_for_gnunet_fh == NULL ||
       gnunet_selector_thread_job_event == NULL)
   {
     GNUNET_break (0);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-         "%s", _("Failed to initialize GNUnet-GTK select\n"));
+                "%s",
+                _ ("Failed to initialize GNUnet-GTK select\n"));
     return GNUNET_SYSERR;
   }
 
@@ -547,7 +540,8 @@ gnunet_gtk_select (void *cls,
   /* Optimization hack: assume that at least one of the fds
    * is not NULL and not empty.
    */
-  gnunet_select_result = GNUNET_NETWORK_socket_select (rfds, wfds, efds, timeout_from_delay);
+  gnunet_select_result =
+    GNUNET_NETWORK_socket_select (rfds, wfds, efds, timeout_from_delay);
   if (gnunet_select_result < 0)
     return gnunet_select_result;
 
@@ -559,25 +553,28 @@ gnunet_gtk_select (void *cls,
   if (NULL != ml->gmc)
   {
     g_main_context_prepare (ml->gmc, &max_priority);
-    need_gfds =
-        g_main_context_query (ml->gmc, max_priority, &delay,
-                              ml->cached_poll_array,
-                              ml->cached_poll_array_size);
+    need_gfds = g_main_context_query (ml->gmc,
+                                      max_priority,
+                                      &delay,
+                                      ml->cached_poll_array,
+                                      ml->cached_poll_array_size);
     if (ml->cached_poll_array_size < need_gfds + 1)
     {
       GNUNET_break (0);
-      GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-           _("Ran out of handle space - g_poll() needs %d handles, has %d!\n"),
-           need_gfds + 1, ml->cached_poll_array_size);
+      GNUNET_log (
+        GNUNET_ERROR_TYPE_ERROR,
+        _ ("Ran out of handle space - g_poll() needs %d handles, has %d!\n"),
+        need_gfds + 1,
+        ml->cached_poll_array_size);
       return GNUNET_SYSERR;
     }
   }
   if (timeout.rel_value_us != GNUNET_TIME_UNIT_FOREVER_REL.rel_value_us)
   {
     if (delay >= 0)
-      delay =
-          GNUNET_MIN (timeout.rel_value_us /
-                      GNUNET_TIME_UNIT_MILLISECONDS.rel_value_us, delay);
+      delay = GNUNET_MIN (timeout.rel_value_us /
+                            GNUNET_TIME_UNIT_MILLISECONDS.rel_value_us,
+                          delay);
     else
       delay = timeout.rel_value_us / GNUNET_TIME_UNIT_MILLISECONDS.rel_value_us;
   }
@@ -587,15 +584,14 @@ gnunet_gtk_select (void *cls,
   {
     GNUNET_break (0);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-         "g_poll() returned %d\n",
-         g_poll_result);
+                "g_poll() returned %d\n",
+                g_poll_result);
     return GNUNET_SYSERR;
   }
-  g_poll_result = (GNUNET_YES == handle_gui_events (ml, max_priority, need_gfds)) ? 1 : 0;
+  g_poll_result =
+    (GNUNET_YES == handle_gui_events (ml, max_priority, need_gfds)) ? 1 : 0;
 
-  if ((gnunet_select_result > 0) ||
-      (g_poll_result > 0) ||
-      (delay == 0))
+  if ((gnunet_select_result > 0) || (g_poll_result > 0) || (delay == 0))
   {
     return gnunet_select_result + g_poll_result;
   }
@@ -616,7 +612,8 @@ gnunet_gtk_select (void *cls,
   sp->wfds = wfds;
   sp->efds = efds;
 
-  sp->timeout = GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MILLISECONDS, delay);
+  sp->timeout =
+    GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MILLISECONDS, delay);
   ml->cached_poll_array[need_gfds].fd = (intptr_t) gnunet_woke_up_event;
   ml->cached_poll_array[need_gfds].events = G_IO_IN;
 
@@ -632,11 +629,12 @@ gnunet_gtk_select (void *cls,
 
   wait_result = WaitForSingleObject (gnunet_woke_up_event, INFINITE);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-       "Finished waiting for the gnunet select thread: %lu %d\n",
-       wait_result,
-       sp->status);
+              "Finished waiting for the gnunet select thread: %lu %d\n",
+              wait_result,
+              sp->status);
 
-  g_poll_result = (GNUNET_YES == handle_gui_events (ml, max_priority, need_gfds)) ? 1 : 0;
+  g_poll_result =
+    (GNUNET_YES == handle_gui_events (ml, max_priority, need_gfds)) ? 1 : 0;
 
   if (-1 == sp->status)
   {
@@ -675,7 +673,8 @@ gnunet_gtk_select (void *cls,
  * @return number of selected sockets, GNUNET_SYSERR on error
  */
 static int
-gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
+gnunet_gtk_select (void *cls,
+                   struct GNUNET_NETWORK_FDSet *rfds,
                    struct GNUNET_NETWORK_FDSet *wfds,
                    struct GNUNET_NETWORK_FDSet *efds,
                    const struct GNUNET_TIME_Relative timeout)
@@ -728,15 +727,14 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
     isset[0] = (rfds == NULL) ? 0 : FD_ISSET (i, &rfds->sds);
     isset[1] = (wfds == NULL) ? 0 : FD_ISSET (i, &wfds->sds);
     isset[2] = (efds == NULL) ? 0 : FD_ISSET (i, &efds->sds);
-    if ((!isset[0]) && (!isset[1]) && (!isset[2]))
+    if ((! isset[0]) && (! isset[1]) && (! isset[2]))
       continue;
     if (fd_counter >= ml->cached_poll_array_size)
       resize_cached_poll_array (ml, ml->cached_poll_array_size * 2);
     ml->cached_poll_array[fd_counter].fd = i;
     ml->cached_poll_array[fd_counter].events =
-        (isset[0] ? G_IO_IN | G_IO_HUP | G_IO_ERR : 0) | (isset[1] ? G_IO_OUT |
-                                                          G_IO_ERR : 0) |
-        (isset[2] ? G_IO_ERR : 0);
+      (isset[0] ? G_IO_IN | G_IO_HUP | G_IO_ERR : 0) |
+      (isset[1] ? G_IO_OUT | G_IO_ERR : 0) | (isset[2] ? G_IO_ERR : 0);
     fd_counter++;
   }
 
@@ -747,9 +745,11 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
     while (1)
     {
       need_gfds =
-          g_main_context_query (ml->gmc, max_priority, &delay,
-                                &ml->cached_poll_array[fd_counter],
-                                ml->cached_poll_array_size - fd_counter);
+        g_main_context_query (ml->gmc,
+                              max_priority,
+                              &delay,
+                              &ml->cached_poll_array[fd_counter],
+                              ml->cached_poll_array_size - fd_counter);
       if (ml->cached_poll_array_size >= need_gfds + fd_counter)
         break;
       resize_cached_poll_array (ml, fd_counter + need_gfds);
@@ -758,16 +758,18 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
   if (timeout.rel_value_us != GNUNET_TIME_UNIT_FOREVER_REL.rel_value_us)
   {
     if (delay >= 0)
-      delay =
-          GNUNET_MIN (timeout.rel_value_us /
-                      GNUNET_TIME_UNIT_MILLISECONDS.rel_value_us, delay);
+      delay = GNUNET_MIN (timeout.rel_value_us /
+                            GNUNET_TIME_UNIT_MILLISECONDS.rel_value_us,
+                          delay);
     else
       delay = timeout.rel_value_us / GNUNET_TIME_UNIT_MILLISECONDS.rel_value_us;
   }
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "We have %d of our FDs and %d of GMC ones, going to wait %6dms\n",
-              fd_counter, need_gfds, delay);
+              fd_counter,
+              need_gfds,
+              delay);
   poll_result = g_poll (ml->cached_poll_array, fd_counter + need_gfds, delay);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "g_poll returned : %d\n", poll_result);
   if (-1 == poll_result)
@@ -784,10 +786,11 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
                               max_priority,
                               &ml->cached_poll_array[fd_counter],
                               need_gfds))
-      GNUNET_SCHEDULER_add_with_reason_and_priority (&dispatch_gtk_task,
-                                                     ml,
-                                                     GNUNET_SCHEDULER_REASON_STARTUP,
-                                                     GNUNET_SCHEDULER_PRIORITY_UI);
+      GNUNET_SCHEDULER_add_with_reason_and_priority (
+        &dispatch_gtk_task,
+        ml,
+        GNUNET_SCHEDULER_REASON_STARTUP,
+        GNUNET_SCHEDULER_PRIORITY_UI);
   }
   /* Now map back GNUnet scheduler events ... */
   if (NULL != rfds)
@@ -801,11 +804,9 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
     int set = 0;
 
     if ((NULL != rfds) &&
-        (set |=
-         (FD_ISSET (ml->cached_poll_array[ui].fd, &aread) &&
-          (0 !=
-           (ml->cached_poll_array[ui].
-            revents & (G_IO_IN | G_IO_HUP | G_IO_ERR))))))
+        (set |= (FD_ISSET (ml->cached_poll_array[ui].fd, &aread) &&
+                 (0 != (ml->cached_poll_array[ui].revents &
+                        (G_IO_IN | G_IO_HUP | G_IO_ERR))))))
       GNUNET_NETWORK_fdset_set_native (rfds, ml->cached_poll_array[ui].fd);
     if ((NULL != wfds) &&
         (set |=
@@ -813,9 +814,8 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
           (0 != (ml->cached_poll_array[ui].revents & (G_IO_OUT | G_IO_ERR))))))
       GNUNET_NETWORK_fdset_set_native (wfds, ml->cached_poll_array[ui].fd);
     if ((NULL != efds) &&
-        (set |=
-         (FD_ISSET (ml->cached_poll_array[ui].fd, &aexcept) &&
-          (0 != (ml->cached_poll_array[ui].revents & G_IO_ERR)))))
+        (set |= (FD_ISSET (ml->cached_poll_array[ui].fd, &aexcept) &&
+                 (0 != (ml->cached_poll_array[ui].revents & G_IO_ERR)))))
       GNUNET_NETWORK_fdset_set_native (efds, ml->cached_poll_array[ui].fd);
     if (set)
       result++;
@@ -836,7 +836,9 @@ gnunet_gtk_select (void *cls, struct GNUNET_NETWORK_FDSet *rfds,
  * @param cfg handle to the configuration
  */
 static void
-run_main_loop (void *cls, char *const *args, const char *cfgfile,
+run_main_loop (void *cls,
+               char *const *args,
+               const char *cfgfile,
                const struct GNUNET_CONFIGURATION_Handle *cfg)
 {
   struct GNUNET_GTK_MainLoop *ml = cls;
@@ -862,7 +864,8 @@ run_main_loop (void *cls, char *const *args, const char *cfgfile,
   (void) GNUNET_CONFIGURATION_load_from (gcfg, baseconfig);
   GNUNET_free (baseconfig);
   /* FIXME: this was supposed to search the GTK-IPK, so the logic here is badly broken now */
-  if (NULL == (ipath2 = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DATADIR)))
+  if (NULL ==
+      (ipath2 = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DATADIR)))
   {
     GNUNET_break (0);
     return;
@@ -870,16 +873,14 @@ run_main_loop (void *cls, char *const *args, const char *cfgfile,
   if (0 != strcmp (ipath, ipath2))
   {
     GNUNET_asprintf (&baseconfig, "%s%s", ipath2, "config.d");
-    if (GNUNET_YES ==
-	GNUNET_DISK_directory_test (baseconfig, GNUNET_YES))
+    if (GNUNET_YES == GNUNET_DISK_directory_test (baseconfig, GNUNET_YES))
       (void) GNUNET_CONFIGURATION_load_from (gcfg, baseconfig);
     GNUNET_free (baseconfig);
   }
   GNUNET_free (ipath2);
   GNUNET_free (ipath);
 
-  if (GNUNET_YES ==
-      GNUNET_DISK_file_test (cfgfile))
+  if (GNUNET_YES == GNUNET_DISK_file_test (cfgfile))
     (void) GNUNET_CONFIGURATION_parse (gcfg, cfgfile);
   ml->rs = GNUNET_NETWORK_fdset_create ();
   ml->ws = GNUNET_NETWORK_fdset_create ();
@@ -896,9 +897,9 @@ run_main_loop (void *cls, char *const *args, const char *cfgfile,
   GNUNET_SCHEDULER_set_select (&gnunet_gtk_select, ml);
 
   /* keep Gtk event loop running even if there are no GNUnet tasks */
-  ml->dummy_task =
-      GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_FOREVER_REL,
-                                    &keepalive_task, ml);
+  ml->dummy_task = GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_FOREVER_REL,
+                                                 &keepalive_task,
+                                                 ml);
 
   /* run main task of the application */
   GNUNET_SCHEDULER_add_with_reason_and_priority (ml->main_task,
@@ -922,8 +923,9 @@ run_main_loop (void *cls, char *const *args, const char *cfgfile,
  */
 int
 GNUNET_GTK_main_loop_start (const char *binary_name,
-			    const char *binary_help,
-                            int argc, char *const *argv,
+                            const char *binary_help,
+                            int argc,
+                            char *const *argv,
                             struct GNUNET_GETOPT_CommandLineOption *options,
                             const char *main_window_file,
                             GNUNET_SCHEDULER_TaskCallback main_task)
@@ -934,9 +936,13 @@ GNUNET_GTK_main_loop_start (const char *binary_name,
   memset (&ml, 0, sizeof (ml));
   ml.main_window_file = main_window_file;
   ml.main_task = main_task;
-  ret = GNUNET_PROGRAM_run (argc, argv, binary_name,
-                            binary_help, options,
-                            &run_main_loop, &ml);
+  ret = GNUNET_PROGRAM_run (argc,
+                            argv,
+                            binary_name,
+                            binary_help,
+                            options,
+                            &run_main_loop,
+                            &ml);
   if (NULL != ml.cached_poll_array)
     g_free (ml.cached_poll_array);
   if (NULL != ml.rs)
