@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -35,7 +35,7 @@ GNUNET_GTK_set_icon_search_path ()
 {
   char *buf;
 
-  buf = GNUNET_GTK_installation_get_path (GNUNET_OS_IPK_ICONDIR);
+  buf = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_ICONDIR);
   gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), buf);
   GNUNET_free (buf);
 }
@@ -52,8 +52,8 @@ GNUNET_GTK_get_data_dir ()
 {
   static char *dd;
 
-  if (dd == NULL)
-    dd = GNUNET_GTK_installation_get_path (GNUNET_OS_IPK_DATADIR);
+  if (NULL == dd)
+    dd = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DATADIR);
   return dd;
 }
 
@@ -68,25 +68,25 @@ GNUNET_GTK_get_data_dir ()
  * @return TRUE on success, FALSE on errors
  */
 gboolean
-GNUNET_GTK_get_tree_string (GtkTreeView * treeview, GtkTreePath * treepath,
-                            guint column, gchar ** value)
+GNUNET_GTK_get_tree_string (GtkTreeView *treeview,
+                            GtkTreePath *treepath,
+                            guint column,
+                            gchar **value)
 {
   gboolean ok;
   GtkTreeModel *model;
-
-  model = gtk_tree_view_get_model (treeview);
-  if (!model)
-    return FALSE;
-
   GtkTreeIter iter;
 
+  model = gtk_tree_view_get_model (treeview);
+  if (! model)
+    return FALSE;
   ok = gtk_tree_model_get_iter (model, &iter, treepath);
-  if (!ok)
+  if (! ok)
     return FALSE;
 
   *value = NULL;
   gtk_tree_model_get (model, &iter, column, value, -1);
-  if (*value == NULL)
+  if (NULL == *value)
     return FALSE;
   return TRUE;
 }
@@ -113,15 +113,14 @@ GNUNET_GTK_get_new_builder2 (const char *filename,
 
   ret = gtk_builder_new ();
   gtk_builder_set_translation_domain (ret, "gnunet-gtk");
-  GNUNET_asprintf (&glade_path, "%s%s",
-                   GNUNET_GTK_get_data_dir (),
-                   filename);
+  GNUNET_asprintf (&glade_path, "%s%s", GNUNET_GTK_get_data_dir (), filename);
   error = NULL;
   if (0 == gtk_builder_add_from_file (ret, glade_path, &error))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Failed to load `%s': %s\n"),
-                glade_path, error->message);
+                _ ("Failed to load `%s': %s\n"),
+                glade_path,
+                error->message);
     g_error_free (error);
     GNUNET_free (glade_path);
     return NULL;
@@ -144,8 +143,7 @@ GNUNET_GTK_get_new_builder2 (const char *filename,
  * @param root root of the subtree to remove
  */
 void
-GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore * ts,
-					GtkTreeIter * root)
+GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts, GtkTreeIter *root)
 {
   GtkTreeIter child;
 
