@@ -1655,7 +1655,16 @@ launch_edit_dialog (gint n_type,
                     unsigned int off)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc;
+  const char *typename;
 
+  typename = GNUNET_GNSRECORD_number_to_typename (n_type);
+  if (NULL == typename)
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+		"Record type `%u' not supported by this installation\n",
+		(unsigned int) n_type);
+    return;
+  }
   if (NULL == current_pseudonym)
   {
     GNUNET_break (0);
@@ -1694,7 +1703,7 @@ launch_edit_dialog (gint n_type,
   edc->check_validity = &check_validity;
   GNUNET_asprintf (&edc->liblow,
                    "libgnunet_plugin_gtk_namestore_%s",
-                   GNUNET_GNSRECORD_number_to_typename (n_type));
+                   typename);
   GNUNET_STRINGS_utf8_tolower (edc->liblow, edc->liblow);
   edc->plugin = GNUNET_PLUGIN_load (edc->liblow, edc);
   if (NULL == edc->plugin)
@@ -3304,7 +3313,9 @@ run (void *cls)
 int
 main (int argc, char *const *argv)
 {
-  struct GNUNET_GETOPT_CommandLineOption options[] = {GNUNET_GETOPT_OPTION_END};
+  struct GNUNET_GETOPT_CommandLineOption options[] = {
+    GNUNET_GETOPT_OPTION_END
+  };
   int ret;
 
   if (GNUNET_OK ==
