@@ -404,7 +404,8 @@ static struct PortSpecification port_specifications[] =
  * Find spinbutton associated with a port specification.
  *
  * @param i index of the respective port specification
- * @return spinbutton or NULL in case of an error or if respecitve transport is disabled
+ * @return spinbutton or NULL in case of an error or if respecitve transport is
+ * disabled
  */
 static GtkSpinButton *
 get_port_spinbutton (unsigned int i)
@@ -1175,7 +1176,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "topology",
    "FRIENDS-ONLY",
    gettext_noop ("Should GNUnet exclusively connect to friends?"),
-   "https://old.gnunet.org/configuration-f2f",
+   "https://docs.gnunet.org/#Configuring-the-Friend_002dto_002dFriend-_0028F2F_0029-mode",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -1188,7 +1189,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "topology",
    "MINIMUM-FRIENDS",
    gettext_noop ("Minimum number of friendly connections"),
-   "https://old.gnunet.org/configuration-f2f",
+   "https://docs.gnunet.org/#Configuring-the-Friend_002dto_002dFriend-_0028F2F_0029-mode",
    &load_number,
    &save_number,
    NULL,
@@ -1201,7 +1202,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "topology",
    "FORCESTART",
    gettext_noop ("Topology should always be loaded"),
-   "https://old.gnunet.org/configuration-topology",
+   "",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -1215,7 +1216,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "FORCESTART",
    gettext_noop (
      "Should hostlist support be started automatically on startup?"),
-   "https://old.gnunet.org/configuration-hostlist",
+   "https://docs.gnunet.org/#Configuring-the-hostlist-to-bootstrap",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -1228,7 +1229,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "fs",
    "FORCESTART",
    gettext_noop ("Should file-sharing be started automatically on startup?"),
-   "https://old.gnunet.org/configuration-fs",
+   "https://docs.gnunet.org/#Configuring-the-file_002dsharing-service",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -1241,7 +1242,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "OPTIONS",
    gettext_noop ("Should GNUnet learn about other peers using hostlists"),
-   "https://old.gnunet.org/configuration-hostlist",
+   "https://docs.gnunet.org/#Configuring-the-hostlist-to-bootstrap",
    &load_option_list,
    &save_option_list,
    "-b",
@@ -1254,7 +1255,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "OPTIONS",
    gettext_noop ("Should GNUnet learn hostlists from other peers"),
-   "https://old.gnunet.org/configuration-hostlist",
+   "https://docs.gnunet.org/#Configuring-the-hostlist-to-bootstrap",
    &load_option_list,
    &save_option_list,
    "-e",
@@ -1267,7 +1268,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "OPTIONS",
    gettext_noop ("Should this peer offer a hostlist to other peers"),
-   "https://old.gnunet.org/configuring-hostlist-bootstrap",
+   "https://docs.gnunet.org/#Configuring-your-peer-to-provide-a-hostlist",
    &load_option_list,
    &save_option_list,
    "-p",
@@ -1280,7 +1281,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "OPTIONS",
    gettext_noop ("Should this peer advertise its hostlist to other peers"),
-   "https://old.gnunet.org/configuring-hostlist-bootstrap",
+   "https://docs.gnunet.org/#Configuring-your-peer-to-provide-a-hostlist",
    &load_option_list,
    &save_option_list,
    "-a",
@@ -1293,7 +1294,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "HTTPPORT",
    gettext_noop ("Port this peers hostlist should be offered on"),
-   "https://old.gnunet.org/configuring-hostlist-bootstrap",
+   "https://docs.gnunet.org/#Configuring-your-peer-to-provide-a-hostlist",
    &load_number,
    &save_number,
    NULL,
@@ -1332,7 +1333,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL,
    NULL, /* FIXME */
    gettext_noop ("Known hostlist URLs"),
-   "https://old.gnunet.org/configuration-hostlist",
+   "https://docs.gnunet.org/#Configuring-the-hostlist-to-bootstrap",
    NULL,
    NULL,
    NULL, /* FIXME */
@@ -1345,7 +1346,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Do not use a proxy to download hostlists"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "NONE",
@@ -1358,7 +1359,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Use an HTTP proxy"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "HTTP",
@@ -1371,7 +1372,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Use an HTTP v1.0 (only) proxy"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "HTTP_1_0",
@@ -1384,7 +1385,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v4 proxy"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS4",
@@ -1397,7 +1398,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v4a proxy"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS4a",
@@ -1410,7 +1411,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v5 proxy"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS5",
@@ -1423,7 +1424,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v5 proxy with hostname"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS5_HOSTNAME",
@@ -1436,7 +1437,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY",
    gettext_noop ("Specify hostname or IP (and optionally) port of the proxy"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_text,
    &save_text,
    NULL,
@@ -1449,7 +1450,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_USERNAME",
    gettext_noop ("Specify username for the proxy (if needed)"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_text,
    &save_text,
    NULL,
@@ -1462,7 +1463,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "hostlist",
    "PROXY_PASSWORD",
    gettext_noop ("Specify password for the proxy (if needed)"),
-   "https://old.gnunet.org/configuration-hostlist-proxy",
+   "https://docs.gnunet.org/#Configuration-of-the-HOSTLIST-proxy-settings",
    &load_text,
    &save_text,
    NULL,
@@ -1475,7 +1476,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "ats",
    "WAN_QUOTA_OUT",
    gettext_noop ("How many bytes per second are we allowed to transmit?"),
-   "https://old.gnunet.org/configuration-bandwidth",
+   "https://docs.gnunet.org/#Bandwidth-Configuration",
    &load_number,
    &save_number,
    NULL,
@@ -1503,7 +1504,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via TCP"),
-   "https://old.gnunet.org/configuration-tcp",
+   "https://docs.gnunet.org/#Configuring-the-transport-service-and-plugins",
    &load_option_list,
    &save_option_list,
    "tcp",
@@ -1516,7 +1517,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via UDP"),
-   "https://old.gnunet.org/configuration-udp",
+   "https://docs.gnunet.org/#Configuring-the-transport-service-and-plugins",
    &load_option_list,
    &save_option_list,
    "udp",
@@ -1529,7 +1530,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via HTTP as a server"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list,
    &save_option_list,
    "http_server",
@@ -1542,7 +1543,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via HTTP as a client"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list,
    &save_option_list,
    "http_client",
@@ -1555,7 +1556,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via HTTPS as a server"),
-   "https://old.gnunet.org/configuration-https",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list,
    &save_option_list,
    "https_server",
@@ -1568,7 +1569,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via HTTPS as a client"),
-   "https://old.gnunet.org/configuration-https",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list,
    &save_option_list,
    "https_client",
@@ -1581,7 +1582,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via DV"),
-   "https://old.gnunet.org/configuration-dv",
+   "https://docs.gnunet.org/#Distance_002dVector-plugin",
    &load_option_list,
    &save_option_list,
    "dv",
@@ -1594,7 +1595,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport",
    "PLUGINS",
    gettext_noop ("Enable communication via WLAN"),
-   "https://old.gnunet.org/configuration-wlan",
+   "https://docs.gnunet.org/#WLAN-plugin",
    &load_option_list,
    &save_option_list,
    "wlan",
@@ -1607,7 +1608,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-tcp",
    "PORT",
    gettext_noop ("Port we bind to for TCP"),
-   "https://old.gnunet.org/configuration-tcp",
+   "https://docs.gnunet.org/#Configuring-the-transport-service-and-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1620,7 +1621,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-tcp",
    "ADVERTISED_PORT",
    gettext_noop ("Port visible to other peers"),
-   "https://old.gnunet.org/configuration-tcp",
+   "https://docs.gnunet.org/#Configuring-the-transport-service-and-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1633,7 +1634,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-udp",
    "PORT",
    gettext_noop ("Port for inbound UDP packets, use 0 if behind NAT"),
-   "https://old.gnunet.org/configuration-udp",
+   "https://docs.gnunet.org/#Configuring-the-transport-service-and-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1646,7 +1647,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-udp",
    "ADVERTISED_PORT",
    gettext_noop ("Port visible to other peers"),
-   "https://old.gnunet.org/configuration-udp",
+   "https://docs.gnunet.org/#Configuring-the-transport-service-and-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1659,7 +1660,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_server",
    "PORT",
    gettext_noop ("Port for inbound HTTP connections, use 0 if behind NAT"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1672,7 +1673,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_server",
    "ADVERTISED_PORT",
    gettext_noop ("Port visible to other peers"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1685,7 +1686,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_server",
    "PORT",
    gettext_noop ("Port for inbound HTTPS connections, use 0 if behind NAT"),
-   "https://old.gnunet.org/configuration-https",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1698,7 +1699,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_server",
    "ADVERTISED_PORT",
    gettext_noop ("Port visible to other peers"),
-   "https://old.gnunet.org/configuration-https",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_number,
    &save_number,
    NULL,
@@ -1711,7 +1712,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_TYPE",
    gettext_noop ("Do not use a proxy with the HTTP plugin"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "NONE",
@@ -1724,7 +1725,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_TYPE",
    gettext_noop ("Use an HTTP proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "HTTP",
@@ -1737,7 +1738,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v4 proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS4",
@@ -1750,7 +1751,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v4a proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS4a",
@@ -1763,7 +1764,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v5 proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS5",
@@ -1776,7 +1777,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v5 proxy with hostname"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS5_HOSTNAME",
@@ -1789,7 +1790,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY",
    gettext_noop ("Specify hostname or IP (and optionally) port of the proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_text,
    &save_text,
    NULL,
@@ -1802,7 +1803,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_USERNAME",
    gettext_noop ("Specify username for the proxy (if needed)"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_text,
    &save_text,
    NULL,
@@ -1815,7 +1816,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-http_client",
    "PROXY_PASSWORD",
    gettext_noop ("Specify password for the proxy (if needed)"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_text,
    &save_text,
    NULL,
@@ -1831,7 +1832,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_TYPE",
    gettext_noop ("Do not use a proxy for HTTPS plugin"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "NONE",
@@ -1844,7 +1845,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_TYPE",
    gettext_noop ("Use an HTTP proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "HTTP",
@@ -1857,7 +1858,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v4 proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS4",
@@ -1870,7 +1871,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v4a proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS4a",
@@ -1883,7 +1884,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v5 proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS5",
@@ -1896,7 +1897,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_TYPE",
    gettext_noop ("Use a SOCKS v5 proxy with hostname"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "SOCKS5_HOSTNAME",
@@ -1909,7 +1910,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY",
    gettext_noop ("Specify hostname or IP (and optionally) port of the proxy"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_text,
    &save_text,
    NULL,
@@ -1922,7 +1923,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_USERNAME",
    gettext_noop ("Specify username for the proxy (if needed)"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_text,
    &save_text,
    NULL,
@@ -1935,7 +1936,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-https_client",
    "PROXY_PASSWORD",
    gettext_noop ("Specify password for the proxy (if needed)"),
-   "https://old.gnunet.org/configuration-http",
+   "https://docs.gnunet.org/#Configuration-of-the-HTTP-and-HTTPS-transport-plugins",
    &load_text,
    &save_text,
    NULL,
@@ -1951,7 +1952,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "QUOTA",
    gettext_noop (
      "How many bytes are we allowed to store in the local datastore?"),
-   "https://old.gnunet.org/datastore-quota",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_number,
    &save_number,
    NULL,
@@ -1964,7 +1965,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore",
    "DATABASE",
    gettext_noop ("Use sqLite to store file-sharing content"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "sqlite",
@@ -1977,7 +1978,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore",
    "DATABASE",
    gettext_noop ("Use MySQL to store file-sharing content"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "mysql",
@@ -1990,7 +1991,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore",
    "DATABASE",
    gettext_noop ("Use Postgres to store file-sharing content"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "postgres",
@@ -2003,7 +2004,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore-mysql",
    "DATABASE",
    gettext_noop ("Name for the MySQL database"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_text,
    &save_text,
    NULL,
@@ -2029,7 +2030,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore-mysql",
    "USER",
    gettext_noop ("Username for MySQL access"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_text,
    &save_text,
    NULL,
@@ -2042,7 +2043,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore-mysql",
    "PASSWORD",
    gettext_noop ("Password for MySQL access"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_text,
    &save_text,
    NULL,
@@ -2055,7 +2056,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore-mysql",
    "HOST",
    gettext_noop ("Name of host running MySQL database"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_text,
    &save_text,
    NULL,
@@ -2068,7 +2069,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "datastore-mysql",
    "PORT",
    gettext_noop ("Port of MySQL database"),
-   "https://old.gnunet.org/configuration-datastore",
+   "https://docs.gnunet.org/#Configuring-the-datastore",
    &load_number,
    &save_number,
    NULL,
@@ -2095,7 +2096,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "fs",
    "CONTENT_PUSHING",
    gettext_noop ("Should we try to push our content to other peers?"),
-   "https://old.gnunet.org/configuration-fs",
+   "https://docs.gnunet.org/#Configuring-the-file_002dsharing-service",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2108,7 +2109,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "fs",
    "CONTENT_CACHING",
    gettext_noop ("Are we allowed to cache content received from other peers?"),
-   "https://old.gnunet.org/configuration-fs",
+   "https://docs.gnunet.org/#Configuring-the-file_002dsharing-service",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2123,7 +2124,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "QUOTA",
    gettext_noop (
      "How many bytes are we allowed to store in the local datacache?"),
-   "https://old.gnunet.org/datacache-quota",
+   "https://docs.gnunet.org/#Configuring-the-datacache",
    &load_number,
    &save_number,
    NULL,
@@ -2137,7 +2138,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "dhtcache",
    "DATABASE",
    gettext_noop ("Use sqLite to cache DHT data"),
-   "https://old.gnunet.org/configuration-datacache",
+   "https://docs.gnunet.org/#Configuring-the-datacache",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "sqlite",
@@ -2150,7 +2151,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "dhtcache",
    "DATABASE",
    gettext_noop ("Use memory to cache DHT data"),
-   "https://old.gnunet.org/configuration-datacache",
+   "https://docs.gnunet.org/#Configuring-the-datacache",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "heap",
@@ -2163,7 +2164,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "dhtcache",
    "DATABASE",
    gettext_noop ("Use Postgres to cache DHT data"),
-   "https://old.gnunet.org/configuration-datacache",
+   "https://docs.gnunet.org/#Configuring-the-datacache",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "postgres",
@@ -2176,7 +2177,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "transport-wlan",
    "INTERFACE",
    gettext_noop ("Name of monitoring interface to use (monX)"),
-   "https://old.gnunet.org/configuration-wlan",
+   "https://docs.gnunet.org/#Configuring-the-WLAN-transport-plugin",
    &load_text,
    &save_text,
    NULL,
@@ -2204,7 +2205,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "vpn",
    "FORCESTART",
    gettext_noop ("Should the VPN be started automatically on startup?"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2217,7 +2218,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "pt",
    "FORCESTART",
    gettext_noop ("Should the PT be started automatically on startup?"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2231,7 +2232,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "pt",
    "TUNNEL_IPV4",
    gettext_noop ("Tunnel IPv4 traffic over GNUnet"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2245,7 +2246,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "pt",
    "TUNNEL_IPV6",
    gettext_noop ("Tunnel IPv6 traffic over GNUnet"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2258,7 +2259,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "pt",
    "TUNNEL_DNS",
    gettext_noop ("Tunnel DNS traffic over GNUnet"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2271,7 +2272,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "vpn",
    "IFNAME",
    gettext_noop ("Name of the virtual interface the GNUnet VPN should create"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_text,
    &save_text,
    NULL,
@@ -2284,7 +2285,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "vpn",
    "IPV4ADDR",
    gettext_noop ("IPv4 address to use for the VPN interface"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_text,
    &save_text,
    NULL,
@@ -2297,7 +2298,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "vpn",
    "IPV4MASK",
    gettext_noop ("IPv4 network mask to use for the VPN interface"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_text,
    &save_text,
    NULL,
@@ -2310,7 +2311,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "vpn",
    "IPV6ADDR",
    gettext_noop ("IPv6 address to use for the VPN interface"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_text,
    &save_text,
    NULL,
@@ -2323,7 +2324,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "vpn",
    "IPV6PREFIX",
    gettext_noop ("IPv6 network prefix length to use for the VPN interface"),
-   "https://old.gnunet.org/configuration-vpn",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN",
    &load_number,
    &save_number,
    NULL,
@@ -2340,7 +2341,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "FORCESTART",
    gettext_noop (
      "Activate the VPN exit to provide services and/or to enable others to use your Internet connection"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2354,7 +2355,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "DNS_RESOLVER",
    gettext_noop (
      "IP address of the external DNS resolver to use (values from your resolve.conf are usually appropriate))"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2368,7 +2369,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "EXIT_DNS",
    gettext_noop (
      "Allow other peers to perform DNS resolutions using your Internet connection"),
-   "https://old.gnunet.org/configuration-dns",
+   "https://docs.gnunet.org/#IP-Address-of-external-DNS-resolver",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2382,7 +2383,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "TUN_IFNAME",
    gettext_noop (
      "Name of the virtual interface the GNUnet exit service should create for traffic exiting the VPN to the Internet"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2395,7 +2396,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "exit",
    "IPV4ADDR",
    gettext_noop ("IPv4 address to use for the Exit interface"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2408,7 +2409,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "exit",
    "IPV4MASK",
    gettext_noop ("IPv4 network mask to use for the Exit interface"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2421,7 +2422,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "exit",
    "IPV6ADDR",
    gettext_noop ("IPv6 address to use for the Exit interface"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2434,7 +2435,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "exit",
    "IPV6PREFIX",
    gettext_noop ("IPv6 network prefix length to use for the Exit interface"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_number,
    &save_number,
    NULL,
@@ -2449,7 +2450,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "EXIT_IPV4",
    gettext_noop (
      "Allow other users to use your Internet connection for UDP traffic (via the Exit interface)"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2463,7 +2464,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "EXIT_IPV6",
    gettext_noop (
      "Allow other users to use your Internet connection for TCP traffic (via the Exit interface)"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2478,7 +2479,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "EXIT_RANGE_IPV4_POLICY",
    gettext_noop (
      "Which IPv4 addresses and ports do you allow other users to send traffic towards (via the Exit interface)"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2493,7 +2494,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "EXIT_RANGE_IPV6_POLICY",
    gettext_noop (
      "Which IPv6 addresses and ports do you allow other users to send traffic towards (via the Exit interface)"),
-   "https://old.gnunet.org/configuration-exit",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_text,
    &save_text,
    NULL,
@@ -2509,7 +2510,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "namestore",
    "DATABASE",
    gettext_noop ("Use sqLite to store names"),
-   "https://old.gnunet.org/configuration-namestore",
+   "",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "sqlite",
@@ -2522,7 +2523,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "namestore",
    "DATABASE",
    gettext_noop ("Use PostGres to store names"),
-   "https://old.gnunet.org/configuration-namestore",
+   "",
    &load_option_list /* abuse! */,
    &save_option_list /* abuse! */,
    "postgres",
@@ -2551,7 +2552,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    "gns",
    "FORCESTART",
    gettext_noop ("Should the GNS be started automatically on startup?"),
-   "https://old.gnunet.org/configuration-gns",
+   "https://docs.gnunet.org/#Configuring-the-GNU-Name-System",
    &load_yes_no,
    &save_yes_no,
    NULL,
@@ -2567,7 +2568,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL,
    NULL,
    gettext_noop ("Specification of .gnunet hosted services"),
-   "https://old.gnunet.org/configuration-dns",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    &load_hosted_service_configuration,
    NULL,
    NULL,
@@ -2580,7 +2581,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL,
    NULL,
    NULL,
-   "https://old.gnunet.org/configuration-dns",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    NULL,
    &hosted_service_name_install_edited_handler,
    NULL,
@@ -2593,7 +2594,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL,
    NULL,
    NULL,
-   "https://old.gnunet.org/configuration-dns",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    NULL,
    &hosted_service_is_udp_install_toggled_handler,
    NULL,
@@ -2606,7 +2607,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL,
    NULL,
    NULL,
-   "https://old.gnunet.org/configuration-dns",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    NULL,
    &hosted_service_visible_port_install_edited_handler,
    NULL,
@@ -2619,7 +2620,7 @@ const struct GNUNET_SETUP_OptionSpecification option_specifications[] = {
    NULL,
    NULL,
    NULL,
-   "https://old.gnunet.org/configuration-dns",
+   "https://docs.gnunet.org/#Configuring-the-GNUnet-VPN-Exit-Service",
    NULL,
    &hosted_service_destination_install_edited_handler,
    NULL,
